@@ -1,4 +1,5 @@
 from abc import ABC
+from contextlib import contextmanager
 from dataclasses import dataclass, field
 from datetime import datetime
 from pathlib import Path
@@ -7,6 +8,7 @@ from typing import (
     Any,
     Collection,
     Dict,
+    Generator,
     Iterable,
     List,
     Mapping,
@@ -18,6 +20,7 @@ from typing import (
 
 from fsspec.spec import AbstractFileSystem
 from funcy.objects import cached_property
+from rich.progress import Progress
 
 from ldb.dataset import (
     get_annotation,
@@ -50,6 +53,7 @@ from ldb.index.utils import (
 )
 from ldb.params import ParamConfig, ParamFunc
 from ldb.path import InstanceDir
+from ldb.progress import get_progressbar
 from ldb.storage import StorageLocation
 from ldb.typing import JSONDecoded, JSONObject
 from ldb.utils import (
@@ -139,6 +143,7 @@ class Preprocessor(ParamConfig):
         self.params = self.process_params(params, fmt)
 
     def get_storage_files(self) -> FSPathsMapping:
+        print("Collecting paths...")
         return expand_indexing_paths(
             self.paths,
             self.storage_locations,
@@ -181,6 +186,7 @@ class Indexer(ABC):
         self.ephemeral_remote = ephemeral_remote
         self.result = IndexingResult()
         self.hashes: Dict[AbstractFileSystem, Dict[str, str]] = {}
+        self.disable_progress_bar = False
 
     def index(self) -> None:
         try:
@@ -195,6 +201,14 @@ class Indexer(ABC):
     def process_files(self) -> Any:
         raise NotImplementedError
 
+    @contextmanager
+    def progress_bar(self) -> Generator[Progress, None, None]:
+        with get_progressbar(
+            transient=True,
+            disable=self.disable_progress_bar,
+        ) as progress:
+            yield progress
+
 
 class PairIndexer(Indexer):
     def __init__(
@@ -348,29 +362,38 @@ class PairIndexer(Indexer):
         indexing_jobs: IndexingJobMapping,
         annotation_paths: FSPathsMapping,
     ) -> None:
-        for fs, jobs in indexing_jobs.items():
-            fs_annotation_paths = set(annotation_paths.get(fs, []))
-            for config, path_seq in jobs:
-                for data_object_path in path_seq:
-                    annotation_path = data_object_path_to_annotation_path(
-                        data_object_path,
-                    )
-                    try:
-                        fs_annotation_paths.remove(
-                            annotation_path,
-                        )
-                    except KeyError:
-                        annotation_path = ""
-                    if not self.strict_format or annotation_path:
-                        obj_result = self.index_single_pair(
-                            fs,
+        num_files = sum(
+            len(path_seq)
+            for jobs in indexing_jobs.values()
+            for _, path_seq in jobs
+        )
+        print("Indexing data...")
+        with self.progress_bar() as bar:
+            task = bar.add_task("index_files", total=num_files)
+            for fs, jobs in indexing_jobs.items():
+                fs_annotation_paths = set(annotation_paths.get(fs, []))
+                for config, path_seq in jobs:
+                    for data_object_path in path_seq:
+                        annotation_path = data_object_path_to_annotation_path(
                             data_object_path,
-                            config.save_data_object_path_info,
-                            annotation_path,
-                            self.tags,
-                            self.annot_merge_strategy,
                         )
-                        self.result.append(obj_result)
+                        try:
+                            fs_annotation_paths.remove(
+                                annotation_path,
+                            )
+                        except KeyError:
+                            annotation_path = ""
+                        if not self.strict_format or annotation_path:
+                            obj_result = self.index_single_pair(
+                                fs,
+                                data_object_path,
+                                config.save_data_object_path_info,
+                                annotation_path,
+                                self.tags,
+                                self.annot_merge_strategy,
+                            )
+                            self.result.append(obj_result)
+                        bar.update(task, advance=1)
 
     def index_single_pair(
         self,
